@@ -19,15 +19,20 @@ from typing import Dict, Type
 from .base import BackupForGKETransport
 from .grpc import BackupForGKEGrpcTransport
 from .grpc_asyncio import BackupForGKEGrpcAsyncIOTransport
+from .rest import BackupForGKERestTransport
+from .rest import BackupForGKERestInterceptor
 
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[BackupForGKETransport]]
 _transport_registry["grpc"] = BackupForGKEGrpcTransport
 _transport_registry["grpc_asyncio"] = BackupForGKEGrpcAsyncIOTransport
+_transport_registry["rest"] = BackupForGKERestTransport
 
 __all__ = (
     "BackupForGKETransport",
     "BackupForGKEGrpcTransport",
     "BackupForGKEGrpcAsyncIOTransport",
+    "BackupForGKERestTransport",
+    "BackupForGKERestInterceptor",
 )
